
#ifndef KDEGAMESPRIVATE_EXPORT_H
#define KDEGAMESPRIVATE_EXPORT_H

#ifdef LIBKDEGAMESPRIVATE_STATIC_DEFINE
#  define KDEGAMESPRIVATE_EXPORT
#  define LIBKDEGAMESPRIVATE_NO_EXPORT
#else
#  ifndef KDEGAMESPRIVATE_EXPORT
#    ifdef KF5KDEGamesPrivate_EXPORTS
        /* We are building this library */
#      define KDEGAMESPRIVATE_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define KDEGAMESPRIVATE_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef LIBKDEGAMESPRIVATE_NO_EXPORT
#    define LIBKDEGAMESPRIVATE_NO_EXPORT 
#  endif
#endif

#ifndef KDE_DEPRECATED
#  define KDE_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KDE_DEPRECATED_EXPORT
#  define KDE_DEPRECATED_EXPORT KDEGAMESPRIVATE_EXPORT KDE_DEPRECATED
#endif

#ifndef KDE_DEPRECATED_NO_EXPORT
#  define KDE_DEPRECATED_NO_EXPORT LIBKDEGAMESPRIVATE_NO_EXPORT KDE_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef LIBKDEGAMESPRIVATE_NO_DEPRECATED
#    define LIBKDEGAMESPRIVATE_NO_DEPRECATED
#  endif
#endif

#endif
